##  IT Components Out of Scope
The following items are not included in the reference catalog:
  * Minor, patch, and build versions, as well as editions of commercial and open-source software products that do not provide individual end-of-life information. These are represented in the relevant Major.x or Major.minor.x versions of the same product.
  * Client software that has an auto-upgrade feature or is typically managed by a Mobile Device Management (MDM) solution
  * Mobile applications and websites that primarily focus on B2C or that are solely used to provide information without functionality that allows them to be embedded in other applications (for example, Amazon, eBay, Facebook)
  * Software libraries
  * APIs (that are not offered standalone)
  * Plug-ins and add-ons for platforms, except for major plug-ins and add-ons of top vendors
  * Command-line utilities (for example, grep, awk, sed)
  * Hardware drivers and firmware
